const Lang = imports.lang;
const Main = imports.ui.main;

//CONFIGURATION

//please change from true to false in order to hide workspace selector and vice versa
const WORKSPACE_SELECTOR_SHOW = true;

//when flag is set to false then for best results gnome-shell.css in /usr/share/gnome-shell/theme/ 
//(for Adwaita) or your custom gnome-shell's theme css file needs adjusting: 
//please set visible-width to 0px (from whatever value that is found there, likely 32px)
//.workspace-controls {
//    visible-width: 0px; /* Amount visible before hovering */
//}

//mind that css change needs reverting when one would like to see workspace selector again by 
//setting flag to true or by disabling Light Overview extension

function init() {
	return new LightOverview();
}

function LightOverview() {
    this._init();
}

LightOverview.prototype = {
	_init: function() {
		//search
		this.searchTab = Main.overview._viewSelector._searchTab;
		this.oldStartSearch = this.searchTab.startSearch;

		//dash
		this.showingId = null;
		this.hidingId = null;
		// store the values we are going to override
		this.old_x = Main.overview._viewSelector.actor.x;
		this.old_width = Main.overview._viewSelector.actor.get_width();
	},
	
	enable: function() {
		//workspace selector
		//stop updating alwaysZoomOut flag for a timebeing of extension
		//otherwise right margin will be floating upon opening/closing workspaces
		this.old_updateAlwaysZoom = Main.overview._workspacesDisplay._updateAlwaysZoom;
		Main.overview._workspacesDisplay._updateAlwaysZoom = function () {};		
		if (WORKSPACE_SELECTOR_SHOW) {
			//never hide workspace selector
			Main.overview._workspacesDisplay._alwaysZoomOut = true;
		} else {
			Main.overview._workspacesDisplay._alwaysZoomOut = false;
		}
		this.showingId = Main.overview.connect("showing", Lang.bind(this, this.showOverview));
		this.hidingId = Main.overview.connect("hiding", Lang.bind(this, this.hideOverview));
	},
	
	disable: function() {
		Main.overview.disconnect(this.showingId);
		Main.overview.disconnect(this.hidingId);
		this.revertAllChanges();
	},

	showOverview: function() {
		//activities/applications buttons
		Main.overview._viewSelector._tabBox.hide();

		//message tray
		Main.messageTray._corner.set_reactive(false);
		Main.messageTray.actor.hide();
		
		//search
		this.searchTab.startSearch = function(event){};
		this.searchTab._entry.hide();

		//workspace selector
		if (WORKSPACE_SELECTOR_SHOW) {
			//Main.overview._workspacesDisplay._alwaysZoomOut = true;
		} else {
			Main.overview._workspacesDisplay.actor.hide(); //thumbnails, controls
		}
		
		//dash
		Main.overview._dash.actor.hide();
		Main.overview._viewSelector.actor.set_x(0);
		Main.overview._viewSelector.actor.set_width(Main.overview._group.get_width());
	},
	
	hideOverview: function() {
		//message tray
		Main.messageTray.actor.show();
		Main.messageTray._corner.set_reactive(true);
	},

	revertAllChanges: function() {
		//activities/applications buttons
		Main.overview._viewSelector._tabBox.show();

		//message tray
		//hideOverview does a trick

		//search
		this.searchTab.startSearch = this.oldStartSearch;
		this.searchTab._entry.show();

		//workspace selector
		if (WORKSPACE_SELECTOR_SHOW) {
			//do nothing
		} else {
			Main.overview._workspacesDisplay.actor.show();
		}
		Main.overview._workspacesDisplay._updateAlwaysZoom = this.old_updateAlwaysZoom;
		Main.overview._workspacesDisplay._alwaysZoomOut = false;
		Main.overview._workspacesDisplay._zoomOut = false;
		Main.overview._workspacesDisplay._updateAlwaysZoom();
		Main.overview._workspacesDisplay._updateZoom();
	
		//dash
		Main.overview._dash.actor.show();
		Main.overview._viewSelector.actor.set_x(this.old_x);
		Main.overview._viewSelector.actor.set_width(this.old_width);
	}
};
